/*
 * CTU Open Contest 2010
 *
 * Sample solution: Arbitrage
 * Author: Jan Stoklasa
 */

#include <iostream>
#include <string>
#include <vector>
#include <map>
#include <math.h>
 #include<stdexcept>

using namespace std;

const int MAX_CURRENCIES=200;
map<string,int> currencies;

int primes[] = {2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47,
	53, 59, 61, 67, 71, 73, 79, 83, 89, 97, 101}; 
const int NPrimes = sizeof(primes)/sizeof(primes[0]);

class Rational
{
    bool zero;
    int power[NPrimes];
public:
    Rational()
    {
        zero = true;
    }

    Rational(int x)
    {            
        if (x == 0)
            zero = true;
        else
        {
            zero = false;
            for (int i = 0; i < NPrimes; i++)
            {
                power[i] = 0;
                while (x > 0 && x % primes[i] == 0)
                {
                    x /= primes[i];
                    power[i]++;
                }
            }
        }
    }

    Rational operator*(const Rational& y);
    Rational operator/(const Rational& y);
    bool operator>(const Rational& y);
};

Rational Rational::operator*(const Rational& y)
{
    Rational z; 
    if (zero || y.zero)
    {
        z.zero = true; 
    }
    else
    {
        z.zero = false;
        for (int i = 0; i < NPrimes; i++)
            z.power[i] = power[i] + y.power[i];
    }
    return z;
}

Rational Rational::operator/(const Rational& y)
{
    Rational z;   
    if (zero)
    {
        z.zero = true;
    }
    else if (y.zero)
    {
        throw runtime_error("Denominator of a rational is zero");
    }
    else
    {
        z.zero = false;
        for (int i = 0; i < NPrimes; i++)
            z.power[i] = power[i] - y.power[i];
    }
    return z;
}

bool Rational::operator>(const Rational& y)
{
    if (zero && y.zero)
        return false;
    else if (!zero && y.zero)
        return true;
    else if (zero && !y.zero)
        return false;
    Rational z = *(this) / y;
    double logarithm = 0.0;
    for (int i = 0; i < NPrimes; i++)
        logarithm += (double)(z.power[i]) * log((double)primes[i]);
    return logarithm > 0;
}

Rational exchange[MAX_CURRENCIES][MAX_CURRENCIES];
int main(int argc, char* argv[])
{
    for(;;)
    {
        int N;
        cin >> N;
        if (!N) break;
        for(int i=0;i<N;i++)
        {
            string currency;
            cin >> currency;
            currencies[currency] = i;
        }

        int M;
        cin >> M;

        for(int i = 0; i < N; i++)
            for(int j = 0; j < N; j++)
            {
                exchange[i][j]=0;
            }

        for(int i = 0; i < N; i++)
        {
            exchange[i][i]=1;
        }

        for(int i = 0; i < M; i++)
        {
            string s1, s2;
            int numerator, denominator;
            char skip;
            cin >> s1 >> s2 >> denominator >> skip >> numerator; 
            exchange[currencies[s1]][currencies[s2]] = Rational(numerator)/Rational(denominator);
        }

        bool consistent = true;
        for(int k=0;k<N;k++)
            for(int i=0;i<N;i++)	
                for(int j=0;j<N;j++)
                {
                    Rational r = exchange[i][k] * exchange[k][j];
                    if(r > exchange[i][j])
                    {
                        exchange[i][j] = r;
                        if (i == j && exchange[i][j] > Rational(1)) 
                        {
                            consistent = false;
                            goto found;
                        }   
                    }
                }

found:  if (consistent)
            cout << "Ok" << endl;
        else
            cout << "Arbitrage" << endl;
    }
    return 0;
}
