/*
 * CTU Open Contest 2010
 *
 * Alternative solution for problem Fumar
 * (slower than the other one)
 *
 * Author: Zdenek Dvorak
 */

#include <stdio.h>
#include <math.h>

#define EPS 0.001

static int d, rx, ry, n;
static struct {int fx, fy, tx, ty;} town[200];

static double
pdist(double x, double y, double ax, double ay)
{
  x -= ax;
  y -= ay;
  return sqrt (x * x + y * y);
}

static double
bdist(double x, double y, int i)
{
  if (x < town[i].fx)
    {
      if (y < town[i].fy)
	return pdist (x, y, town[i].fx, town[i].fy);
      else if (y > town[i].ty)
	return pdist (x, y, town[i].fx, town[i].ty);
      else
	return town[i].fx - x;
    }
  else if (x > town[i].tx)
    {
      if (y < town[i].fy)
	return pdist (x, y, town[i].tx, town[i].fy);
      else if (y > town[i].ty)
	return pdist (x, y, town[i].tx, town[i].ty);
      else
	return x - town[i].tx;
    }
  else
    {
      if (y < town[i].fy)
	return town[i].fy - y;
      else if (y > town[i].ty)
	return y - town[i].ty;
      else
	return 0;
    }
}

static double
distance (double x, double y)
{
  double mdist = 1e6;
  int i;

  for (i = 0; i < n; i++)
    {
      double adist = bdist (x, y, i);
      if (adist < mdist)
	mdist = adist;
    }

  return mdist;
}

static int
check (double x, double y)
{
  if (x >= 0 && x <= rx && y >= 0 && y <= ry && distance (x, y) > d - EPS)
    {
      printf ("%.2f %.2f\n", x, y);
      return 1;
    }
  else
    return 0;
}

static int
check_hline_circle (double ly, double x, double y)
{
  double delta_y = ly - y;
  double delta_xsq = d * d - delta_y * delta_y;
  double delta_x;

  if (delta_xsq < 0)
    return 0;

  delta_x = sqrt (delta_xsq);
  return check (x + delta_x, ly) || check (x - delta_x, ly);
}

static int
check_vline_circle (double lx, double x, double y)
{
  double delta_x = lx - x;
  double delta_ysq = d * d - delta_x * delta_x;
  double delta_y;

  if (delta_ysq < 0)
    return 0;

  delta_y = sqrt (delta_ysq);
  return check (lx, y + delta_y) || check (lx, y - delta_y);
}

static int
check_circle_circle (double x1, double y1, double x2, double y2)
{
  double pd = pdist (x1, y1, x2, y2);
  double cdelta = pd / (2 * d);
  double ang, delta;

  if (cdelta > 1)
    return 0;

  ang = atan2 (y2 - y1, x2 - x1);
  delta = acos (cdelta);

  return (check (x1 + d * cos (ang + delta), y1 + d * sin (ang + delta))
	  || check (x1 + d * cos (ang - delta), y1 + d * sin (ang - delta)));
}

static int
check_building_hline (int b, double y)
{
  return (check (town[b].fx - d, y)
	  || check (town[b].tx + d, y)
	  || check_hline_circle (y, town[b].fx, town[b].fy)
	  || check_hline_circle (y, town[b].fx, town[b].ty)
	  || check_hline_circle (y, town[b].tx, town[b].fy)
	  || check_hline_circle (y, town[b].tx, town[b].ty));
}

static int
check_building_vline (int b, double x)
{
  return (check (x, town[b].fy - d)
	  || check (x, town[b].ty + d)
	  || check_vline_circle (x, town[b].fx, town[b].fy)
	  || check_vline_circle (x, town[b].fx, town[b].ty)
	  || check_vline_circle (x, town[b].tx, town[b].fy)
	  || check_vline_circle (x, town[b].tx, town[b].ty));
}

static int
check_building_circle (int b, double x, double y)
{
  return (check_circle_circle (x, y, town[b].fx, town[b].fy)
	  || check_circle_circle (x, y, town[b].fx, town[b].ty)
	  || check_circle_circle (x, y, town[b].tx, town[b].fy)
	  || check_circle_circle (x, y, town[b].tx, town[b].ty));
}
static int
check_building_building (int b1, int b2)
{
  return (check_building_vline (b1, town[b2].fx - d)
	  || check_building_vline (b1, town[b2].tx + d)
	  || check_building_hline (b1, town[b2].fy - d)
	  || check_building_hline (b1, town[b2].ty + d)
	  || check_building_circle (b1, town[b2].fx, town[b2].fy)
	  || check_building_circle (b1, town[b2].fx, town[b2].ty)
	  || check_building_circle (b1, town[b2].tx, town[b2].fy)
	  || check_building_circle (b1, town[b2].tx, town[b2].ty));
}

int main(void)
{
  int i, j;

  while (scanf ("%d%d%d%d", &d, &rx, &ry, &n) == 4)
    {
      if (d==0) break;
      for (i = 0; i < n; i++)
	scanf ("%d%d%d%d", &town[i].fx, &town[i].fy, &town[i].tx, &town[i].ty);

      if (check (0, 0) || check (rx, 0) || check (0, ry) || check (rx, ry))
	continue;

      for (i = 0; i < n; i++)
	{
  	  if (check_building_hline (i, 0)
  	      || check_building_vline (i, 0)
  	      || check_building_hline (i, ry)
  	      || check_building_vline (i, rx))
	    break;

	  for (j = i + 1; j < n; j++)
	    if (check_building_building (i, j))
	      break;
	  if (j < n)
	    break;
	}
      if (i == n)
	printf ("Smoking not permitted!\n");
    }
  return 0;
}
