/*
 * CTU Open Contest 2010
 *
 * Sample solution: Fumar
 * Author: Zdenek Dvorak
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#define min(X,Y) ((X) < (Y) ? (X) : (Y))
#define max(X,Y) ((X) > (Y) ? (X) : (Y))
#define EPS 0.0001

typedef struct {int fx, fy, tx, ty;} rectangle;
typedef struct {int x, y;} circle;
typedef struct {double f, t;} interval;

static int d, rx, ry, n;
static rectangle budovy[200];

#define ROTATE_POINT(X,Y) do {typeof(X) tmpx = (X); (X) = (Y); (Y) = rx - tmpx;} while (0)

static void
rotate_frame (void)
{
  int x = 0, y = ry;
  ROTATE_POINT (x, y);
  rx = x; ry = y;
}

static void
rotate (void)
{
  int i, tmp;

  for (i = 0; i < n; i++)
    {
      ROTATE_POINT (budovy[i].fx, budovy[i].fy);
      ROTATE_POINT (budovy[i].tx, budovy[i].ty);
      tmp = budovy[i].ty;
      budovy[i].ty = budovy[i].fy;
      budovy[i].fy = tmp;
    }
  rotate_frame ();
}

static int
intersect_line_rectangle (int ly, int lfx, int ltx, rectangle *with, interval *rslt)
{
  if (ly <= with->fy || with->ty <= ly || ltx < with->fx || with->tx < lfx)
    return 0;

  rslt->f = max (lfx, with->fx);
  rslt->t = min (ltx, with->tx);
  return 1;
}

static int
intersect_line_circle (int ly, int lfx, int ltx, circle *with, interval *rslt)
{
  double dst, dy = ly - with->y;

  dst = d * d - dy * dy;
  if (dst < 0)
    return 0;
  dst = sqrt (dst);
  rslt->f = max (lfx, with->x - dst);
  rslt->t = min (ltx, with->x + dst);
  return 1;
}

static int
in_rectangle (int x, int y, rectangle *wh)
{
  return (x >= wh->fx && x <= wh->tx && y >= wh->fy && y <= wh->ty);
}

static int
insersect_arc_line_x (int ax, int ay, int y, int fx, int tx, double *ian)
{
  double x;

  if (y > ay + d || y < ay)
    return 0;

  *ian = asin ((double) (y - ay) / d);
  x = ax + d * cos (*ian);
  if (x < fx - EPS || x > tx + EPS)
    return 0;

  return 1;
}

static int
insersect_arc_line_y (int ax, int ay, int x, int fy, int ty, double *ian)
{
  double y;

  if (x > ax + d || x < ax)
    return 0;

  *ian = acos ((double) (x - ax) / d);
  y = ay + d * sin (*ian);
  if (y < fy - EPS || y > ty + EPS)
    return 0;

  return 1;
}

static int
intersect_arc_rectangle (int ax, int ay, rectangle *with, interval *rslt)
{
  if (in_rectangle (ax, ay + d, with))
    rslt->t = M_PI / 2;
  else if (!insersect_arc_line_y (ax, ay, with->fx, with->fy, with->ty, &rslt->t)
	   && !insersect_arc_line_x (ax, ay, with->ty, with->fx, with->tx, &rslt->t))
    return 0;
  if (in_rectangle (ax + d, ay, with))
    rslt->f = 0;
  else if (!insersect_arc_line_y (ax, ay, with->tx, with->fy, with->ty, &rslt->f)
	   && !insersect_arc_line_x (ax, ay, with->fy, with->fx, with->tx, &rslt->f))
    { printf("ERROR\n"); return 1; }

  return 1;
}

static int
intersect_arc_circle (int ax, int ay, circle *with, interval *rslt)
{
  double join_angle, delta_angle, dst, dx = ax - with->x, dy = ay - with->y;
  
  if (ax == with->x && ay == with->y)
    return 0;

  join_angle = atan2 (with->y - ay, with->x - ax);
  dst = sqrt (dx * dx + dy * dy);
  if (dst > 2 * d)
    return 0;
  delta_angle = acos (dst / (2 * d));

  if (join_angle + delta_angle < 0 || join_angle - delta_angle > M_PI / 2)
    return 0;

  rslt->f = max (join_angle - delta_angle, 0);
  rslt->t = min (join_angle + delta_angle, M_PI / 2);
  return 1;
}


static interval ints[10000];
static int nint;

static int
compint (const void *a, const void *b)
{
  interval *ia = (interval *) a;
  interval *ib = (interval *) b;

  if (ia->f < ib->f)
    return -1;
  else if (ia->f > ib->f)
    return 1;
  else
    return 0;
}

static int
uncovered (interval *what, double *uncp)
{
  int act;
  double last_covered = what->f;

  qsort (ints, nint, sizeof (interval), compint);

  for (act = 0; act < nint; act++)
    {
      if (ints[act].f > what->t)
	break;

      if (ints[act].f > last_covered + EPS)
	{
	  *uncp = last_covered;
	  return 1;
	}

      if (ints[act].t > last_covered)
	last_covered = ints[act].t;
    }

  if (last_covered < what->t - EPS)
    {
      *uncp = last_covered;
      return 1;
    }

  return 0;
}

static rectangle *
rect (int fx, int fy, int tx, int ty)
{
  static rectangle ret;

  ret.fx = fx;
  ret.fy = fy;
  ret.tx = tx;
  ret.ty = ty;
  return &ret;
}

static circle *
circ (int x, int y)
{
  static circle ret;

  ret.x = x;
  ret.y = y;
  return &ret;
}

static int
test_line (int ly, int lfx, int ltx, double *x, double *y)
{
  interval whole;
  rectangle *b;
  int i;

  if (!intersect_line_rectangle (ly, lfx, ltx, rect(0,0,rx,ry), &whole))
    return 0;

  nint = 0;
  for (i = 0; i < n; i++)
    {
      b = budovy + i;
      if (intersect_line_rectangle (ly, lfx, ltx, rect (b->fx, b->fy-d, b->tx, b->ty+d), ints + nint))
	nint++;
      if (intersect_line_rectangle (ly, lfx, ltx, rect (b->fx-d, b->fy, b->tx+d, b->ty), ints + nint))
	nint++;
      if (intersect_line_circle (ly, lfx, ltx, circ (b->fx, b->fy), ints + nint))
	nint++;
      if (intersect_line_circle (ly, lfx, ltx, circ (b->fx, b->ty), ints + nint))
	nint++;
      if (intersect_line_circle (ly, lfx, ltx, circ (b->tx, b->fy), ints + nint))
	nint++;
      if (intersect_line_circle (ly, lfx, ltx, circ (b->tx, b->ty), ints + nint))
	nint++;
    }

  *y = ly;
  return uncovered (&whole, x);
}

static int
test_arc (int ax, int ay, double *x, double *y)
{
  interval whole;
  rectangle *b;
  double ang;
  int i;

  if (!intersect_arc_rectangle (ax, ay, rect(0,0,rx,ry), &whole))
    return 0;

  nint = 0;
  for (i = 0; i < n; i++)
    {
      b = budovy + i;
      if (intersect_arc_rectangle (ax, ay, rect (b->fx, b->fy-d, b->tx, b->ty+d), ints + nint))
	nint++;
      if (intersect_arc_rectangle (ax, ay, rect (b->fx-d, b->fy, b->tx+d, b->ty), ints + nint))
	nint++;
      if (intersect_arc_circle (ax, ay, circ (b->fx, b->fy), ints + nint))
	nint++;
      if (intersect_arc_circle (ax, ay, circ (b->fx, b->ty), ints + nint))
	nint++;
      if (intersect_arc_circle (ax, ay, circ (b->tx, b->fy), ints + nint))
	nint++;
      if (intersect_arc_circle (ax, ay, circ (b->tx, b->ty), ints + nint))
	nint++;
    }

  if (!uncovered (&whole, &ang))
    return 0;

  *x = ax + d * cos (ang);
  *y = ay + d * sin (ang);
  return 1;
}

static int
test_lines (double *x, double *y)
{
  int i;

  for (i = 0; i < n; i++)
    if (test_line (budovy[i].fy - d, budovy[i].fx, budovy[i].tx, x, y)
	|| test_line (budovy[i].ty + d, budovy[i].fx, budovy[i].tx, x, y))
      return 1;
  return 0;
}

static int
test_arcs (double *x, double *y)
{
  int i;

  for (i = 0; i < n; i++)
    if (test_arc (budovy[i].tx, budovy[i].ty, x, y))
      return 1;
  return 0;
}

int main(void)
{
  int i;
  double x, y;

  while (scanf ("%d%d%d%d", &d, &rx, &ry, &n) == 4)
    {
      if (d == 0) break;
      for (i = 0; i < n; i++)
	scanf ("%d%d%d%d", &budovy[i].fx, &budovy[i].fy, &budovy[i].tx, &budovy[i].ty);

      if (n == 0)
	{
	  printf ("%.2f %.2f\n", 0, 0);
	  continue;
	}

      if (test_lines (&x, &y) || test_arcs (&x, &y))
	{
	  printf ("%.2f %.2f\n", x, y);
	  continue;
	}
      rotate ();
      if (test_lines (&x, &y) || test_arcs (&x, &y))
	{
	  ROTATE_POINT (x, y); rotate_frame ();
	  ROTATE_POINT (x, y); rotate_frame ();
	  ROTATE_POINT (x, y);
	  printf ("%.2f %.2f\n", x, y);
	  continue;
	}
      rotate ();
      if (test_arcs (&x, &y))
	{
	  ROTATE_POINT (x, y); rotate_frame ();
	  ROTATE_POINT (x, y);
	  printf ("%.2f %.2f\n", x, y);
	  continue;
	}
      rotate ();
      if (test_arcs (&x, &y))
	{
	  ROTATE_POINT (x, y);
	  printf ("%.2f %.2f\n", x, y);
	}
      else
	printf ("Smoking not permitted!\n");
    }

  return 0;
}
