/*
 * CTU Open Contest 2010
 *
 * Sample solution: Guard
 * Author: Zdenek Dvorak
 */

#include <stdio.h>
#include <math.h>

#define min(X, Y) ((X) < (Y) ? (X) : (Y))
#define EPS 1e-5

static int
gcd (int a, int b)
{
  int m = 1;

  while (a % 2 == 0 && b % 2 == 0)
    {
      m *= 2;
      a /= 2;
      b /= 2;
    }

  while (1)
    {
      while (a % 2 == 0)
	a /= 2;
      while (b % 2 == 0)
	b /= 2;

      if (a == b)
	return a * m;

      if (a > b)
	a -= b;
      else
	b -= a;
    }
}

typedef struct {double x, y;} point;

static int s1[4], s2[4], s2re[4], tt1, tt2;
static double dist1[4], dist2[4], time1[4], time2[4], tdist1, tdist2;
static double entry_time1[4], entry_time2[4];

static double
dotprod (point p1, point p2)
{
  return p1.x * p2.x + p1.y * p2.y;
}

static double
norm (point p)
{
  return sqrt (dotprod (p, p));
}

static point
diff (point p1, point p2)
{
  point ret;
  ret.x = p1.x - p2.x;
  ret.y = p1.y - p2.y;
  return ret;
}


static int
pos_in_face (double atime, int fce, double tottime, double entry_times[4], double stay_times[4], double *pos)
{
  double delta;
  atime -= tottime * floor (atime / tottime);

  delta = atime - entry_times[fce];
  if (delta < -EPS)
    return 0;
  if (delta < 0)
    {
      *pos = 0;
      return 1;
    }

  if (delta <= stay_times[fce])
    {
      *pos = delta;
      return 1;
    }

  if (delta > stay_times[fce] + EPS)
    return 0;

  *pos = stay_times[fce];
  return 1;
}

static double
mindist (point sp1, point ep1, point sp2, point ep2)
{
  point rels = diff (sp2, sp1);
  point rele = diff (ep2, ep1);
  point dir = diff (rele, rels);
  point cls;
  double nm = dotprod (dir, dir);
  double alpha;
 
  if (nm == 0)
    alpha = 1e6;
  else 
    alpha = - dotprod (rels, dir) / nm;

  if (alpha < 0 || alpha > 1)
    return min (norm (rels), norm (rele));

  cls.x = rels.x + alpha * dir.x;
  cls.y = rels.y + alpha * dir.y;
  return norm (cls);
}

static point
part (double p, point f, point t)
{
  point ret;
  ret.x = (1 - p) * f.x + p * t.x;
  ret.y = (1 - p) * f.y + p * t.y;
  return ret;
}

static const point leftbot = {0,0};
static const point rightbot = {440,0};
static const point top = {220, 356.0898763};
static point
coords (int h, int right)
{
  return part (h / 280.0, right ? rightbot : leftbot, top);
}

static double
distance (int h1, int h2)
{
  point p1 = coords (h1, 0), p2 = coords (h2, 1);
  return norm (diff (p1, p2));
}

int main (void)
{
  int t, i;
  double mind, ad, atime, spos, sptime;
  point f1, t1, f2, t2;

  while (scanf("%d%d%d%d%d%d%d%d%d%d",
	       s1 + 0, s1 + 1, s1 + 2, s1 + 3, &tt1,
	       s2 + 0, s2 + 1, s2 + 2, s2 + 3, &tt2) == 10)
    {
      t = gcd (tt1, tt2);
      tt1 /= t;
      tt2 /= t;

      for (i = 0; i < 4; i++)
	s2re[(6 - i) % 4] = s2[i];
      tdist1 = tdist2 = 0;
      for (i = 0; i < 4; i++)
	{
	  tdist1 += dist1[i] = distance (s1[i], s1[(i + 1) % 4]);
	  tdist2 += dist2[i] = distance (s2re[i], s2re[(i + 1) % 4]);
	}
      for (i = 0; i < 4; i++)
	{
	  time1[i] = tt1 * dist1[i] / tdist1;
	  time2[i] = tt2 * dist2[i] / tdist2;
	}

      entry_time1[0] = 0;
      entry_time2[1] = 0;
      for (i = 1; i < 4; i++)
	{
	  entry_time1[i] = entry_time1[i - 1] + dist1[i - 1] * tt1 / tdist1;
	  entry_time2[(5 - i) % 4] = entry_time2[(6 - i) % 4] + dist2[(6 - i) % 4] * tt2 / tdist2;
	}

      mind = 1e6;
      for (i = 0; i < 4; i++)
	{
	  f1 = coords (s1[i], 0);
	  t1 = coords (s1[(i + 1) % 4], 1);
	  f2 = coords (s2re[(i + 1) % 4], 1);
	  t2 = coords (s2re[i], 0);
	  for (t = 0; t < tt2; t++)
	    {
	      atime = t * tt1 + entry_time1[i];
	      if (!pos_in_face (atime, i, tt2, entry_time2, time2, &spos))
		continue;

	      sptime = min (time1[i], time2[i] - spos);
	      ad = mindist (f1, part (sptime / time1[i], f1, t1),
			    part (spos / time2[i], f2, t2), part ((spos + sptime) / time2[i], f2, t2));
	      mind = min (ad, mind);
	    }

	  for (t = 0; t < tt1; t++)
	    {
	      atime = t * tt2 + entry_time2[i];
	      if (!pos_in_face (atime, i, tt1, entry_time1, time1, &spos))
		continue;

	      sptime = min (time2[i], time1[i] - spos);
	      ad = mindist (f2, part (sptime / time2[i], f2, t2),
			    part (spos / time1[i], f1, t1), part ((spos + sptime) / time1[i], f1, t1));
	      mind = min (ad, mind);
	    }
	}

      printf ("%.3f\n", mind);
    }

  return 0;
}
