/*
 * CTU Open Contest 2010
 *
 * Sample solution: Guard
 * Author: Martin Kacer
 */

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.text.DecimalFormat;
import java.util.StringTokenizer;

public class guard {
	static final double PYR_SIDE = 440, PYR_HEIGHT = 280;
	static final double PYR_DIAG = Math.sqrt(sqr(PYR_SIDE)/2);

	static final double EPS = 1E-7;
	static DecimalFormat OUTFORM = new DecimalFormat("0.000");
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	public static void main(String[] args) throws Exception {
		guard instance = new guard();
		while (instance.run()) {}
	}
	String nextToken() throws Exception {
		while (!st.hasMoreTokens()) st = new StringTokenizer(input.readLine());
		return st.nextToken();
	}
	int nextInt() throws Exception {
		return Integer.parseInt(nextToken());
	}

	static boolean iszero(double x) {
		return x < EPS && x > -EPS;
	}
	static double sqr(double x) {
		return x*x;
	}
	double pyth2(double x1, double y1, double z1,
			double x2, double y2, double z2) {
		return sqr(x1-x2) + sqr(y1-y2) + sqr(z1-z2);
	}

	double mindist2(double xa1, double ya1, double za1,
			double xa2, double ya2, double za2,
			double xb1, double yb1, double zb1,
			double xb2, double yb2, double zb2) {
		double xd1 = xa1 - xb1, yd1 = ya1 - yb1, zd1 = za1 - zb1;
		double xd0 = xa2 - xb2 - xd1, yd0 = ya2 - yb2 - yd1, zd0 = za2 - zb2 - zd1;
		double nom = xd0*xd1 + yd0*yd1 + zd0*zd1;
		double den = sqr(xd0) + sqr(yd0) + sqr(zd0);
		double d1 = pyth2(xa1, ya1, za1, xb1, yb1, zb1);
		double d2 = pyth2(xa2, ya2, za2, xb2, yb2, zb2);
		if (d2 < d1) d1 = d2;
		if (den > EPS && nom < EPS && -nom < den) {
			double t = -nom / den;
			d2 = pyth2(xa1+t*(xa2-xa1), ya1+t*(ya2-ya1), za1+t*(za2-za1),
					xb1+t*(xb2-xb1), yb1+t*(yb2-yb1), zb1+t*(zb2-zb1));
			if (d2 < d1) d1 = d2;
		}
		//System.err.println("MIN: ["+xa1+";"+ya1+";"+za1+"]-["+xa2+";"+ya2+";"+za2+
		//		"] x ["+xb1+";"+yb1+";"+zb1+"]-["+xb2+";"+yb2+";"+zb2+"] ("
		//		+nom+"/"+den+") -> " + d1);
		return d1;
	}

	// coordinates of the four points ([0] repeated at [4])
	double[][] gx = new double[2][5], gy = new double[2][5], gz = new double[2][5];
	double[][] gt = new double[2][4], // time needed to walk the side
			gl = new double[2][4]; // length of the side segment
	int[] gtim = new int[2], // input time
			gi = new int[2]; // at what side is currently located
	double[] gpos = new double[2]; // how much time has elapsed
	double[] grestim = new double[2]; // how much time to the next edge
	double[][] segx = new double[2][2], segy = new double[2][2], segz = new double[2][2];
	double minimum;
	
	void getpos(int g, int segp) {
		int i = gi[g];
		double pt = gpos[g];
		segx[g][segp] = gx[g][i] + (gx[g][i+1]-gx[g][i]) * pt/gt[g][i];
		segy[g][segp] = gy[g][i] + (gy[g][i+1]-gy[g][i]) * pt/gt[g][i];
		segz[g][segp] = gz[g][i] + (gz[g][i+1]-gz[g][i]) * pt/gt[g][i];
	}

	boolean advance() {
		for (int g = 0; g < 2; ++g)
			grestim[g] = gt[g][gi[g]] - gpos[g];
		int shorter = (grestim[0] < grestim[1]) ? 0 : 1;
		boolean same = (gi[0] + gi[1] == 1) || (gi[0] + gi[1] == 5);
		//System.err.println("DBG: "+grestim[0]+" / "+grestim[1]+" -> " + shorter+" "+same);
		for (int g = 0; g < 2; ++g) {
			if (same) getpos(g, 0);
			gpos[g] += grestim[shorter];
			if (same) getpos(g, 1);
		}
		if (same) {
			double d = mindist2(segx[0][0], segy[0][0], segz[0][0],
					segx[0][1], segy[0][1], segz[0][1],
					segx[1][0], segy[1][0], segz[1][0],
					segx[1][1], segy[1][1], segz[1][1]);
			if (d < minimum) minimum = d;
		}
		if (++gi[shorter] == 4) gi[shorter] = 0;
		gpos[shorter] = 0;
		return gi[0] == 0 && gi[1] == 0 && gpos[0] < EPS && gpos[1] < EPS;
	}

	boolean run() throws Exception {
		for (int g = 0; g < 2; ++g) {
			for (int i = 0; i < 4; ++i) {
				gz[g][i] = nextInt();
				gx[g][i] = gy[g][i] = (PYR_HEIGHT-gz[g][i]) * PYR_DIAG / PYR_HEIGHT;
			}
			gx[g][1] = gx[g][3] = gy[g][0] = gy[g][2] = 0;
			gtim[g] = nextInt();
			if (gtim[g] == 0) return false;
		}
		gx[0][0] = -gx[0][0]; gx[1][2] = -gx[1][2];
		gy[0][3] = -gy[0][3]; gy[1][3] = -gy[1][3];
		for (int g = 0; g < 2; ++g) {
			gx[g][4] = gx[g][0]; gy[g][4] = gy[g][0]; gz[g][4] = gz[g][0];
			double len = 0;
			for (int i = 0; i < 4; ++i) {
				len += gl[g][i] = Math.sqrt(pyth2(gx[g][i], gy[g][i], gz[g][i],
						gx[g][i+1], gy[g][i+1], gz[g][i+1]));
			}
			for (int i = 0; i < 4; ++i) {
				gt[g][i] = gtim[g] * gl[g][i] / len;
			}
		}
		/*
		for (int g = 0; g < 2; ++g) {
			for (int i = 0; i < 4; ++i) {
				System.err.println("["+gx[g][i]+";"+gy[g][i]+";"+gz[g][i]+"] t="+gt[g][i]);
			}
			System.err.println();
		}
		*/
		
		gi[0] = gi[1] = 0; gpos[0] = gpos[1] = 0;
		minimum = sqr(PYR_SIDE + PYR_HEIGHT);
		while (!advance()) {
			/*
			for (int g = 0; g < 2; ++g) {
				getpos(g, 0);
				System.err.println(g+": "+gi[g]+"("+gpos[g]+") ["
						+segx[g][0]+";"+segy[g][0]+";"+segz[g][0]+"]");
			}
			*/
		}
		System.out.println(OUTFORM.format(Math.sqrt(minimum+EPS)));
		return true;
	}
}
